package com.mortals.xhx.module.site.service.impl;

import cn.hutool.core.util.ReUtil;
import com.alibaba.fastjson.JSON;
import com.mortals.framework.ap.GlobalSysInfo;
import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.code.DxTypeEnum;
import com.mortals.xhx.common.code.SourceEnum;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.common.key.Constant;
import com.mortals.xhx.common.utils.MatterHtmlParseUtil;
import com.mortals.xhx.common.utils.MatterTypeHtmlParseUtil;
import com.mortals.xhx.module.dept.model.DeptEntity;
import com.mortals.xhx.module.dept.model.DeptQuery;
import com.mortals.xhx.module.site.model.SiteEntity;
import com.mortals.xhx.module.site.model.SiteThemeQuery;
import com.mortals.xhx.module.site.service.SiteService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.site.dao.SiteThemeDao;
import com.mortals.xhx.module.site.model.SiteThemeEntity;
import com.mortals.xhx.module.site.service.SiteThemeService;
import org.springframework.util.ObjectUtils;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.regex.Pattern;

/**
 * SiteThemeService
 * 主题 service实现
 *
 * @author zxfei
 * @date 2022-11-23
 */
@Service("siteThemeService")
public class SiteThemeServiceImpl extends AbstractCRUDServiceImpl<SiteThemeDao, SiteThemeEntity, Long> implements SiteThemeService {


    @Override
    public Rest<String> syncThemeBySiteId(SiteEntity siteEntity, Context context) {
        String url = GlobalSysInfo.getParamValue(Constant.GOV_GR_URL, "http://www.sczwfw.gov.cn/jiq/front/item/gr_index");
        String frurl = GlobalSysInfo.getParamValue(Constant.GOV_FR_URL, "http://www.sczwfw.gov.cn/jiq/front/item/fr_index");
        Long siteId = siteEntity.getId();
        this.deleteGovBySiteId(siteId, context);
        String areaCode = siteEntity.getAreaCode();
        Map<String, String> params = new HashMap<>();
        params.put("areaCode", areaCode);
        Rest<String> grrest = buildTheme(siteId, DxTypeEnum.个人服务.getValue(), url, params, context);
        Rest<String> frrest = buildTheme(siteId, DxTypeEnum.法人服务.getValue(), frurl, params, context);
        if (grrest.getCode() != YesNoEnum.YES.getValue() || frrest.getCode() != YesNoEnum.YES.getValue()) {
            log.info("个人服务结果:" + JSON.toJSONString(grrest));
            log.info("法人服务结果:" + JSON.toJSONString(frrest));
            return Rest.fail("同步主题失败！");
        }

        return Rest.ok("当前站点同步添加主题成功！");
    }

    @Override
    public Rest<String> syncTownThemeBySiteId(SiteEntity siteEntity, Context context) {
        String url = GlobalSysInfo.getParamValue(Constant.GOV_TOWN_URL, "http://www.sczwfw.gov.cn/jiq/front/item/town");
        Long siteId = siteEntity.getId();
        this.deleteGovBySiteId(siteId, context);
        String areaCode = siteEntity.getAreaCode();
        Map<String, String> params = new HashMap<>();
        params.put("areaCode", areaCode);
        Rest<String> townRest = buildTwonTheme(siteId, url, params, context);
        if (townRest.getCode() != YesNoEnum.YES.getValue() ) {
            log.info("服务结果:" + JSON.toJSONString(townRest));
            return Rest.fail("同步乡镇主题失败！");
        }

        return Rest.ok("当前站点同步乡镇添加主题成功！");
    }

    private Rest<String> buildTheme(Long siteId, String userType, String url, Map<String, String> params, Context context) {
        Rest<Map<String, String>> rest = MatterTypeHtmlParseUtil.getThemeList(params, url);
        if (rest.getCode() == YesNoEnum.YES.getValue() && rest.getData().keySet().size() > 0) {
            //删除部门中属于政务部门的
            // deptService.syncDeptBySiteId(siteId, context);
            Map<String, String> data = rest.getData();
            for (Map.Entry<String, String> item : data.entrySet()) {
                String themeCode = item.getKey();
                String themeName = item.getValue();
                if (themeCode.equals("allService") || themeName.equalsIgnoreCase("全部主题")) {
                    continue;
                }
                int count = this.count(new SiteThemeQuery().siteId(siteId).userType(userType).themeCode(themeCode), context);
                if (count == 0) {
                    SiteThemeEntity siteThemeEntity = new SiteThemeEntity();
                    siteThemeEntity.initAttrValue();
                    siteThemeEntity.setSiteId(siteId);
                    siteThemeEntity.setUserType(userType);
                    siteThemeEntity.setThemeCode(themeCode);
                    siteThemeEntity.setThemeName(themeName);
                    siteThemeEntity.setCreateTime(new Date());
                    siteThemeEntity.setCreateUserId(getContextUserId(context));
                    this.save(siteThemeEntity, context);
                }
            }
        } else {
            return Rest.fail(rest.getMsg());
        }
        return Rest.ok(rest.getMsg());
    }


    private Rest<String> buildTwonTheme(Long siteId, String url, Map<String, String> params, Context context) {
        Rest<Map<String, String>> rest = MatterTypeHtmlParseUtil.getTownThemeList(params, url);
        if (rest.getCode() == YesNoEnum.YES.getValue() && rest.getData().keySet().size() > 0) {
            Map<String, String> data = rest.getData();
            for (Map.Entry<String, String> item : data.entrySet()) {
                String[] vals = item.getKey().split("&");
                String themeCode = vals[0];
                String userType = vals[1];
                String themeName = item.getValue();
                int count = this.count(new SiteThemeQuery().siteId(siteId).userType(userType).themeCode(themeCode), context);
                if (count == 0) {
                    SiteThemeEntity siteThemeEntity = new SiteThemeEntity();
                    siteThemeEntity.initAttrValue();
                    siteThemeEntity.setSiteId(siteId);
                    siteThemeEntity.setUserType(userType);
                    siteThemeEntity.setThemeCode(themeCode);
                    siteThemeEntity.setThemeName(themeName);
                    siteThemeEntity.setCreateTime(new Date());
                    siteThemeEntity.setCreateUserId(getContextUserId(context));
                    this.save(siteThemeEntity, context);
                }
            }
        } else {
            return Rest.fail(rest.getMsg());
        }
        return Rest.ok(rest.getMsg());
    }

    @Override
    public void deleteGovBySiteId(Long siteId, Context context) {
        Map<String, Object> condition = new HashMap<>();
        condition.put("siteId", siteId);
        this.dao.delete(condition);
    }


    public static void main(String[] args) {
        String str = "ywblurl('http://www.sczwfw.gov.cn/jiq/front/transition/ywTransToDetail?areaCode=511500000000&amp;itemCode=511A0141700000-511500000000-000-125112007566044888-1-00&amp;taskType=1&amp;deptCode=511501-17','在公路增设或改造平面交叉道口审批')";

/*
        String reg = "'.*?'";

        Pattern compile = Pattern.compile(reg);
*/

        List<String> allGroups = ReUtil.findAllGroup0("'(.*?)'", str);
        allGroups.forEach(item -> {

           // System.out.println(item);
        });


        System.out.println(allGroups.get(0));
    }
}